﻿//
// Copyright (C) 2009 Chris Dziemborowicz
//
// This file is part of Orzeszek Ratings.
//
// Orzeszek Ratings is free software: you can redistribute it and/or
// modify it under the terms of the GNU General Public License as
// published by the Free Software Foundation, either version 3 of the
// License, or (at your option) any later version.
//
// Orzeszek Ratings is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program. If not, see <http://www.gnu.org/licenses/>.
//

using System;
using System.Collections.Generic;
using System.Linq;
using System.Reflection;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;

namespace OrzeszekRatings
{
	/// <summary>
	/// Interaction logic for AboutControl.xaml
	/// </summary>
	public partial class AboutControl : UserControl
	{
		public AboutControl()
		{
			InitializeComponent();

			VersionHyperlink.Inlines.Add(new Run(Assembly.GetExecutingAssembly().GetName().Version.ToString()));
			VersionHyperlink.NavigateUri = new Uri("http://www.orzeszek.org/dev/ratings/");
			VersionHyperlink.RequestNavigate += new RequestNavigateEventHandler(HyperlinkUtility.RequestNavigate);
			LicenseHyperlink.RequestNavigate += new RequestNavigateEventHandler(HyperlinkUtility.RequestNavigate);
		}

		private void AboutButton_Click(object sender, RoutedEventArgs e)
		{
			if (Sizer.HeightFactor == 0)
				AnimateShow();
			else if (Sizer.HeightFactor == 1)
				AnimateHide();
		}

		private void OKButton_Click(object sender, RoutedEventArgs e)
		{
			AnimateHide();
		}

		private void AnimateShow()
		{
			AboutButton.Template = (ControlTemplate)Resources["ActiveButtonTemplate"];

			Sizer.IsEnabled = true;

			DoubleAnimationUsingKeyFrames da = new DoubleAnimationUsingKeyFrames();
			da.KeyFrames.Add(new SplineDoubleKeyFrame(0));
			da.KeyFrames.Add(new SplineDoubleKeyFrame(1, KeyTime.FromTimeSpan(TimeSpan.FromMilliseconds(250))));
			Sizer.BeginAnimation(SizerControl.HeightFactorProperty, da);
		}

		private void AnimateHide()
		{
			AboutButton.Template = (ControlTemplate)Resources["InactiveButtonTemplate"];

			DoubleAnimationUsingKeyFrames da = new DoubleAnimationUsingKeyFrames();
			da.KeyFrames.Add(new SplineDoubleKeyFrame(1));
			da.KeyFrames.Add(new SplineDoubleKeyFrame(0, KeyTime.FromTimeSpan(TimeSpan.FromMilliseconds(250))));
			da.Completed += new EventHandler(delegate(object o, EventArgs ea)
				{
					Sizer.IsEnabled = false;
				}
			);
			Sizer.BeginAnimation(SizerControl.HeightFactorProperty, da);
		}
	}
}